#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-7a8ff0bd98d1e72c778de11c366d8b51
key: asn1p_LrLFPvrxagO8jGmFd1SmqK
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Parse
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-parse-0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-LrLFPvrxagO8jGmFd1SmqK
depends:
    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
    asn1-types-0.3.2-3969820adc8283f126affe054010f830
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
